=========================
 Invenio-Access v1.0.0a6
=========================

Invenio-Access v1.0.0a6 was released on June 13, 2016.

About
-----

Invenio module for common role based access control.

*This is an experimental developer preview release.*

What's new
----------

- Adds 'superuser_access' action. This grants access to all permissions
  checked through DynamicPermissions. Note that granting
  'superuser_access' will make every DynamicPermission deny access by
  default.

Installation
------------

   $ pip install invenio-access==1.0.0a6

Documentation
-------------

   http://pythonhosted.org/invenio-access/

Happy hacking and thanks for flying Invenio-Access.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-access
|   URL: http://invenio-software.org
